#include "dsp56301.h"

////////////////////////////////////////////////////////////////////////////////////////////////
// Available Functions
////////////////////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////////////////////
void DSP563xx_ChangeDataMode(pDSPINFO DSP563xx , DWORD HI32DataMode)
{
	DWORD	Control;
	DWORD	dwReturnValue;
	// resets HF[2:0]
	Control	= DSP563xx_ReadHI32Register(DSP563xx , HCTR_OFFSET);
	Control	= (Control & ~(HCTR_HF0 | HCTR_HF1 | HCTR_HF2 ));
	DSP563xx_WriteHI32Register(DSP563xx , HCTR_OFFSET, Control);

	// send host command : Personal Reset
	DSP563xx_WriteHI32Register(DSP563xx , HCVR_OFFSET, 0xEF);
	// wait for acknowledge from the DSP
	dwReturnValue = DSP563xx_WaitForInterrupt((pDSPINFO)DSP563xx, INFINITE);
	Control	= DSP563xx_ReadHI32Register(DSP563xx , HCTR_OFFSET);
	switch(HI32DataMode) {
		case HI32_32BIT_MODE:
			// program data mode
			Control	= Control & ~(HCTR_HRF1 | HCTR_HRF0 | HCTR_HTF1 | HCTR_HTF0);
			DSP563xx_WriteHI32Register(DSP563xx , HCTR_OFFSET, Control);
			break;
		case HI32_24BIT_MODE:
		default:
			Control	= Control | HCTR_HRF0 | HCTR_HTF0;
			DSP563xx_WriteHI32Register(DSP563xx , HCTR_OFFSET, Control);
	}
}
////////////////////////////////////////////////////////////////////////////////////////////////

BOOL DSP563xx_LoadVxD(pDSPINFO DSP563xx)
{
	if(!DSP563xx_CreateCommonEvent(&DSP563xx->Evnt3, &DSP563xx->Evnt0)) {
		return FALSE;
	}
	DSP563xx->DeviceHandle = CreateFile(DSP563xx->VxDFileName, 0,0,0,CREATE_NEW, 0, 0);
	if (DSP563xx->DeviceHandle  == INVALID_HANDLE_VALUE)
	{
		return FALSE;
	}
	return TRUE;
}
////////////////////////////////////////////////////////////////////////////////////////////////
BOOL DSP563xx_UnLoadVxD(pDSPINFO DSP563xx)
{
	if (CloseHandle(DSP563xx->DeviceHandle))
	{
		if (DeleteFile(DSP563xx->VxDFileName))
		{
			return FALSE;
		}
		return TRUE;
	}
	return FALSE;
}
////////////////////////////////////////////////////////////////////////////////////////////////
BOOL DSP563xx_InitializeDevice(pDSPINFO DSP563xx)
{
	PVOID		InBuf[5];
	PVOID		OutBuf[3];
	DWORD		cbBytesReturned;
	DWORD 		Status;

	InBuf[1] =	DSP563xx->Evnt0;
	InBuf[0] =	(PVOID)INITIALIZATION_MESSAGE;
	InBuf[2] =	(PVOID)DSP563xx->DeviceId;	

	DeviceIoControl(DSP563xx->DeviceHandle, HI32_USER_MESSAGE,InBuf,
		sizeof(PVOID),(LPVOID)OutBuf, sizeof(OutBuf),
		&cbBytesReturned, NULL);
	
	Status	= (DWORD)OutBuf[0];	// Status returned by VxD

	if (Status == DEVNODE_NOT_FOUND) {
		return	FALSE;
	}
	else {
		DSP563xx->HI32BaseAddress = (DWORD)OutBuf[1];	// base address for hi32 mem space
		return	TRUE;
	}
}
////////////////////////////////////////////////////////////////////////////////////////////////
void DSP563xx_WriteHI32Register(pDSPINFO DSP563xx , DWORD	Register, DWORD NewValue)
{
	DWORD*	RegisterAddress;
	RegisterAddress = ((DWORD*)DSP563xx->HI32BaseAddress + Register);
	*RegisterAddress = NewValue;
}
////////////////////////////////////////////////////////////////////////////////////////////////
DWORD DSP563xx_ReadHI32Register(pDSPINFO DSP563xx , DWORD	Register)
{
	DWORD*	RegisterAddress;
	RegisterAddress = ((DWORD*)DSP563xx->HI32BaseAddress + Register);
	return *RegisterAddress;
}

////////////////////////////////////////////////////////////////////////////////////////////////
BOOL DSP563xx_DownloadCode(pDSPINFO DSP563xx , const CHAR *Filename)
{
	BOOL	ReturnValue;
	FILE	*file;
	int		i;
	DWORD	NewValue;
	INT		Size;
	DWORD	Base;
	DWORD*	DSPCode;
	DWORD	Control;
	DWORD	Checksum;
	DWORD	Localsum;
	DSPCode = malloc(0x1000*sizeof(DWORD));

	ReturnValue = TRUE;
	Checksum	= 0;
	Localsum	= 0;
	// read code file (*.pci)
	file = fopen(Filename,"r");
	if(file == NULL )
	{
		ReturnValue = FALSE;
	}
	else
	{
		fscanf(file,"%8lx\n",&Size);	// Base Address
		fscanf(file,"%8lx\n",&Base);	// Number of dwords
		DSPCode[0] = Size;
		DSPCode[1] = Base;
		for (i=2;i<(Size+2);i++)
		{
			fscanf(file,"%8lx\n",&NewValue);
			DSPCode[i]	= NewValue;
		}
		fclose(file);	
	}
	// download code to DSP
	// resets HF[2:0]
	Control	= DSP563xx_ReadHI32Register(DSP563xx , HCTR_OFFSET);
	Control	= (Control & ~(HCTR_HF0 | HCTR_HF1 | HCTR_HF2 ));
	DSP563xx_WriteHI32Register(DSP563xx , HCTR_OFFSET, Control);
	// program data mode
	Control	= DSP563xx_ReadHI32Register(DSP563xx , HCTR_OFFSET);
	Control	= Control & ~(HCTR_HRF1 | HCTR_HRF0 | HCTR_HTF1 | HCTR_HTF0);
	Control	= Control | HCTR_HRF0 | HCTR_HTF0;
	DSP563xx_WriteHI32Register(DSP563xx , HCTR_OFFSET, Control);
	// tx first and second words
	DSP563xx_WriteHI32Register(DSP563xx , HTXR_OFFSET, Size); // number of words
	DSP563xx_WriteHI32Register(DSP563xx , HTXR_OFFSET, Base); // DSP memory base address
	// tx code words
	for (i=2;i<(Size+2);i++)
	{
		DSP563xx_WriteHI32Register(DSP563xx , HTXR_OFFSET, DSPCode[i]); // code word
		Localsum	= Localsum + DSPCode[i];
	}
// END download code to DSP
	Checksum	= DSP563xx_ReadHI32Register(DSP563xx , HRXS_OFFSET);
	Localsum = Localsum & 0x00ffffff;
	if (Checksum!=Localsum)
	{	
		ReturnValue = FALSE;
	}
	else
	{
		ReturnValue = TRUE;
	}
	free(DSPCode);

	return	ReturnValue;
}

////////////////////////////////////////////////////////////////////////////////////////////////
DWORD DSP563xx_WaitForInterrupt(pDSPINFO DSP563xx , DWORD Timeout)
{
	if (WaitForSingleObject((HANDLE)DSP563xx->Evnt3, Timeout) == WAIT_TIMEOUT) {
		return WAIT_TIMEOUT;
	}
	return (0x00000038 & DSP563xx_ReadHI32Register(DSP563xx , HSTR_OFFSET)) >> 3 ;
}
////////////////////////////////////////////////////////////////////////////////////////////////
BOOL DSP563xx_LockMemoryPage(DWORD* LinearAddress , pDSPINFO DSP563xx, DWORD Size)
{
	PVOID		InBuf[3];
	PVOID		OutBuf[2];
	DWORD		cbBytesReturned;
	DWORD		Status;

	InBuf[0] =	(PVOID)LOCK_ONE_MEMORY_PAGE;
	InBuf[1] =	(PVOID)LinearAddress;
	InBuf[2] =	(PVOID)Size;

	DeviceIoControl(DSP563xx->DeviceHandle, HI32_USER_MESSAGE,InBuf,
		sizeof(PVOID),(LPVOID)OutBuf, sizeof(OutBuf),
		&cbBytesReturned, NULL);

	return	(DWORD)OutBuf[0];

	Status			=	(DWORD)OutBuf[0];	
	
	printf ("LOCKED :: %8lx %8lx\n",Status,(DWORD)OutBuf[1]);

	if (Status) {
		return	(DWORD)OutBuf[1];
	}
	else {
		return	FALSE;
	}
}
////////////////////////////////////////////////////////////////////////////////////////////////
BOOL DSP563xx_UnLockMemoryPage(DWORD* LinearAddress , pDSPINFO DSP563xx, DWORD Size)
{
	PVOID		InBuf[3];
	PVOID		OutBuf[2];
	DWORD		cbBytesReturned;

	InBuf[0] =	(PVOID)UNLOCK_ONE_MEMORY_PAGE;
	InBuf[1] =	(PVOID)LinearAddress;
	InBuf[2] =	(PVOID)Size;

	DeviceIoControl(DSP563xx->DeviceHandle, HI32_USER_MESSAGE,InBuf,
		sizeof(PVOID),(LPVOID)OutBuf, sizeof(OutBuf),
		&cbBytesReturned, NULL);
	
	return (BOOL)OutBuf[0]; // status returned by VxD

}
////////////////////////////////////////////////////////////////////////////////////////////////
BOOL DSP563xx_ReadCfgSpace(DWORD CfgOffset, pDSPINFO DSP563xx, DWORD* CfgWord)
{
	PVOID		InBuf[2];
	PVOID		OutBuf[2];
	DWORD		cbBytesReturned;
	DWORD*		Status;

	InBuf[0] =	(PVOID)RD_CNFG_SPACE_MESSAGE;
	InBuf[1] =	(PVOID)CfgOffset;

	DeviceIoControl(DSP563xx->DeviceHandle, HI32_USER_MESSAGE,InBuf,
		sizeof(PVOID),(LPVOID)OutBuf, sizeof(OutBuf),
		&cbBytesReturned, NULL);

	Status	= (DWORD*)OutBuf[0];
	if (Status) {
		*CfgWord	= (DWORD)OutBuf[1];
		return	TRUE;
	}
	else {
		return	FALSE;
	}
}
////////////////////////////////////////////////////////////////////////////////////////////////
BOOL DSP563xx_WriteCfgSpace(DWORD CfgOffset, pDSPINFO DSP563xx, DWORD CfgWord)
{
	PVOID		InBuf[3];
	PVOID		OutBuf[2];
	DWORD		cbBytesReturned;
	DWORD*		Status;

	InBuf[0] =	(PVOID)WR_CNFG_SPACE_MESSAGE;
	InBuf[1] =	(PVOID)CfgOffset;
	InBuf[2] =	(PVOID)CfgWord;

	DeviceIoControl(DSP563xx->DeviceHandle, HI32_USER_MESSAGE,InBuf,
		sizeof(PVOID),(LPVOID)OutBuf, sizeof(OutBuf),
		&cbBytesReturned, NULL);

	Status	= (DWORD*)OutBuf[0];
	if (Status) {
		CfgWord	= (DWORD)OutBuf[1];
		return	TRUE;
	}
	else {
		return	FALSE;
	}
}
////////////////////////////////////////////////////////////////////////////////////////////////
DWORD DSP563xx_GetPhysAdd(DWORD LinAd, pDSPINFO DSP563xx)
{
	PVOID		InBuf[2];
	PVOID		OutBuf[2];
	DWORD		cbBytesReturned;
	DWORD		PhysicalAddress;
	DWORD		ReturnedLinearAddress;

	InBuf[0] =	(PVOID)GET_PHYS_ADD_MESSAGE;
	InBuf[1] =	(PVOID)LinAd;

	DeviceIoControl(DSP563xx->DeviceHandle, HI32_USER_MESSAGE,InBuf,
		sizeof(PVOID),(LPVOID)OutBuf, sizeof(OutBuf),
		&cbBytesReturned, NULL);
	
	ReturnedLinearAddress =	(DWORD)OutBuf[0];	// linear address
	PhysicalAddress =	(DWORD)OutBuf[1];	// base address for a locked buffer

	return	PhysicalAddress;
}

////////////////////////////////////////////////////////////////////////////////////////////////
// COPYRIGHT 1994,1995 Vireos Software, Inc. (portions of this function)
HANDLE (WINAPI *(GetAddressOfOpenVxDHandle()))(HANDLE)
{
	CHAR K32Path[MAX_PATH];
	HINSTANCE hK32;

	GetSystemDirectory(K32Path, MAX_PATH);
	strcat(K32Path, "\\kernel32.dll");
	if ((hK32 = LoadLibrary(K32Path)) == 0)
		return NULL;

	return (HANDLE(WINAPI *)(HANDLE))GetProcAddress(hK32,
		"OpenVxDHandle");
}
////////////////////////////////////////////////////////////////////////////////////////////////
// COPYRIGHT 1994,1995 Vireos Software, Inc. (this function)
BOOL DSP563xx_CreateCommonEvent(HANDLE* Evnt3, HANDLE* Evnt0)
{
	static HANDLE (WINAPI *OpenVxD)(HANDLE)=0;

	*Evnt0 = 0;
	*Evnt3 = CreateEvent(0, FALSE, FALSE, NULL);
	
	if (OpenVxD == 0)
		OpenVxD = GetAddressOfOpenVxDHandle();

	if (OpenVxD && *Evnt3)
		*Evnt0 = OpenVxD(*Evnt3);
	else
		*Evnt0 = 0;

	return ( (*Evnt3 != 0) && (*Evnt0 != 0) );

}
////////////////////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////////////////////
main()
{
////////////////////////////////////
// Some auxiliary variables
////////////////////////////////////
	DWORD*	LinearAddress;

	BOOL	bReturnValue;
	DWORD	dwReturnValue;
	DWORD	dwNewValue;
////////////////////////////////////
// Chip Declaration
////////////////////////////////////
	pDSPINFO DSP56301;
	DSP56301 = malloc(0x400);
	DSP56301->DeviceId = 0x1801;
	DSP56301->VxDFileName  = "\\\\.\\DSPVXD.VXD";
////////////////////////////////////
	printf("*************************************************.\n\n");
	printf("\t\tMOTOROLA INC.\n\n");
	printf("\t\tCOPYRIGHT 1999\n\n");
	printf("\tSample Usage of DSP563xx_PCI_FUNCTIONS\n\n");
	printf("*************************************************.\n");
////////////////////////////////////
// Example of DSP563xx_LoadVxD
////////////////////////////////////
	printf("\nLoading %s : ",DSP56301->VxDFileName);
	bReturnValue = DSP563xx_LoadVxD(DSP56301);
	if (bReturnValue)
	{
		printf(" Passed\n");
	}
	else
	{
		printf(" Failed\n");
	}
////////////////////////////////////
// Example of DSP563xx_InitializeDevice
////////////////////////////////////
	bReturnValue = DSP563xx_InitializeDevice(DSP56301);
	if (bReturnValue)
	{
		printf("\nDevice Initialized. HI32 Memory Base Address: %08lx\n",DSP56301->HI32BaseAddress);
	}
	else
	{
		printf(" Failed Initialize Device\n");
		exit(1);
	}
////////////////////////////////////
// Example of DSP563xx_DownloadCode
////////////////////////////////////
	printf ("\nDownloading code to DSP: ");
	bReturnValue = DSP563xx_DownloadCode(DSP56301, "dsp56301.pci");
	if (bReturnValue) {
		printf(" Passed\n");
	}
	else {
		printf(" Failed\n");
	}
////////////////////////////////////
// Example of DSP563xx_ReadHI32Register
////////////////////////////////////
	printf ("\nReading Registers...\n\n");
	printf ("\tHCTR : %08lx\t",DSP563xx_ReadHI32Register(DSP56301 , HCTR_OFFSET));
	printf ("\tHSTR : %08lx\t",DSP563xx_ReadHI32Register(DSP56301 , HSTR_OFFSET));
	printf ("\tHCVR : %08lx\n",DSP563xx_ReadHI32Register(DSP56301 , HCVR_OFFSET));
////////////////////////////////////
// Example of DSP563xx_WriteHI32Register
////////////////////////////////////
	printf ("\nWriting to HCTR : Setting Host Flags.\n\n");
	dwReturnValue = DSP563xx_ReadHI32Register(DSP56301 , HCTR_OFFSET);
	printf ("\tOld Value of HCTR: %08lx\t",dwReturnValue);
	dwReturnValue = dwReturnValue | 0x00000038;	// set Host Flags HF2..HF0
	DSP563xx_WriteHI32Register(DSP56301 , HCTR_OFFSET, dwReturnValue);
	printf ("\tNew Value of HCTR: %08lx\n",DSP563xx_ReadHI32Register(DSP56301 , HCTR_OFFSET));
	printf ("\nPress <Space> to continue.");
	while (!kbhit()){};
	 _getch();
	printf("\n**************************************************************************\n");
////////////////////////////////////
// Example of Read/Write Config Space
////////////////////////////////////
	printf("\nReading and Writing Configuration Space: clearing BM bit\n\n");
	bReturnValue = DSP563xx_ReadCfgSpace(0x4, DSP56301, &dwReturnValue );
	if (bReturnValue) {
		printf("\tOld Value CSTR/CCMR: %08lx\t",dwReturnValue);
		dwNewValue = dwReturnValue & 0xfffffffb; // clear BM bit
		bReturnValue = DSP563xx_WriteCfgSpace(0x04, DSP56301, dwNewValue );
		if (bReturnValue) {
			bReturnValue = DSP563xx_ReadCfgSpace(0x4, DSP56301, &dwReturnValue );
			if (bReturnValue){
			printf("\tNew Value CSTR/CCMR: %08lx\n",dwReturnValue);
			}
			else {
				printf("\tFailed to Read Configuration Space\n");
			}
		}
		else {
			printf("\tFailed to Write Configuration Space\n");
		}
	}
	else {
		printf("\tFailed to Read Configuration Space\n");
	}
////////////////////////////////////
// Example of using interrupts
////////////////////////////////////
	printf ("\nSending Host Commands: clear HF3, clear HF4, clear HF5\n");
	DSP563xx_WriteHI32Register(DSP56301 , HCVR_OFFSET, 0xF3);
	DSP563xx_WriteHI32Register(DSP56301 , HCVR_OFFSET, 0xF7);
	DSP563xx_WriteHI32Register(DSP56301 , HCVR_OFFSET, 0xFB);
	printf ("Sending Host Commands: set HF3, set HF4\n");
	DSP563xx_WriteHI32Register(DSP56301 , HCVR_OFFSET, 0xF1);
	DSP563xx_WriteHI32Register(DSP56301 , HCVR_OFFSET, 0xF5);
	printf ("Sending Host Command : assert INTA\n");
	DSP563xx_WriteHI32Register(DSP56301 , HCVR_OFFSET, 0xFD);
	printf ("\nWaiting for notification from VxD\n");
//	dwReturnValue = DSP563xx_WaitForInterrupt(DSP56301, 10);//INFINITE);
	dwReturnValue = DSP563xx_WaitForInterrupt(DSP56301, INFINITE);
	if (dwReturnValue == WAIT_TIMEOUT) {
		printf ("\nInterrupted Timed Out\n");
	}
	else {
		printf ("\nReceived Interrupt: %02lx\n", dwReturnValue);
	}
////////////////////////////////////
// Example of DSP563xx_GetPhysAdd
////////////////////////////////////
	printf("\nExample of DSP563xx_GetPhysAdd:\n\n\tGetting the physical memory base address of HI32:");
	printf ("%08lx\n",DSP563xx_GetPhysAdd(DSP56301->HI32BaseAddress, DSP56301));
////////////////////////////////////
// Example of DSP563xx_LockMemoryPage and DSP563xx_UnLockMemoryPage
////////////////////////////////////
	printf("\nExample of DSP563xx_LockMemoryPage and DSP563xx_UnLockMemoryPage:\n\n");
	LinearAddress = (DWORD*)malloc(0x401*sizeof(DWORD));
	printf("Linear Adddress: %08lx",LinearAddress);
	printf("\tLocking:");
	if(DSP563xx_LockMemoryPage(LinearAddress, DSP56301, 0x400*sizeof(DWORD))) {
		printf(" Passed\n");
		dwReturnValue	= DSP563xx_GetPhysAdd((DWORD)LinearAddress, DSP56301);
		printf ("Physical Address: %08lx",dwReturnValue);
		printf("\tUnlocking:");
		if(DSP563xx_UnLockMemoryPage(LinearAddress, DSP56301, 0x400*sizeof(DWORD))) {
			printf(" Passed\n");
		}
		else {
			printf(" Failed\n");
		}
	}
	else {
		printf(" Failed\n");
	}
	free(LinearAddress);
////////////////////////////////////
// Example of DSP563xx_UnLoadVxD
////////////////////////////////////
	printf("\nUnloading VxD:");
	bReturnValue = DSP563xx_UnLoadVxD(DSP56301);
	if (bReturnValue) {
		printf(" Passed\n");
	}
	else {
		printf(" Failed\n");
	}
	printf ("\nPress <Space> to exit.\n");
	while (!kbhit()){};
	 _getch();
	printf("\n**************************************************************************\n");
////////////////////////////////////
// end of program
////////////////////////////////////	
	free(DSP56301);
	return 0;
}