;
;
;	debug.asm
;
;	DSP56K code to implement basic debugging functions including:
;	[s]top DSP
;	[g]o (resume)
;	display registers and compare to previous state
;	display [u]ser stack
;	[c]hange registers
;	[t]race (single step) instruction
;	[b]reakpoints.
;	memory examine and change (using host port I/O)
;
;
;	Copyright  1993 Robert Bristow-Johnson
;	Copyright  1994 crescent engineering
;
;
m4_changecom(';')
m4_changequote([,])
m4_define([MACRO],[m4_define([$1],[$2])])



		include	'56k.inc'
 
REGBASE		equ	$7b73
DEBUG_CODESIZE	equ	$01c8	;IMPORTANT! If you add code to this program, you must
				; increase this value so that REGVAL = REGBASE 

	org	p:STACK_ERROR
	jsr	>(REGVAL-2)	;this vector informs the host as to where the
				; user registers are saved.  Also points
				; to JMP instruction to STACK_ERROR handler.
	org	p:NMI
	jsr	>NMIENT

	org	p:P_SWI
	jsr	>SWIENT


	org P:$40
	jmp >NMIENT
	reti

;	PAGE
	
	org	p:REGBASE-DEBUG_CODESIZE	;this puts the debug code right up against
						; the multisound (or audiomedia) system code.



OP_JSR	equ	$0BF080		;OPCODE FOR "JSR"
OP_SWI	equ	$000006		;OPCODE FOR "SWI"
OP_JMP	equ	$0AF080		;OPCODE FOR "JMP"
OP_NOP	equ	$000000		;OPCODE FOR "NOP"


MACRO([SAVE_USER],
	[
	movem	r0,p:USR_R0
	movem	r1,p:USR_R1
	movec	ssl,r0	
	movec	ssh,r1	
	jsr	SAVE_CONTEXT
])

;SAVE_USE	macro			;MACRO TO SAVE THE USER'S CONTEXT
;	move	r0,p:USR_R0	;SAVE USER R0
;	move	r1,p:USR_R1	;SAVE USER R1
;	move	ssl,r0		;GET USER SR FROM INTERRUPT
;	move	ssh,r1		;GET USER PC FROM INTERRUPT
;	jsr	SAVE_CONTEXT	;SAVE THE USER'S CONTEXT
;	endm
			

;	PAGE



;
;	TRA [N]	 TRACE N INSTRUCTIONS
;	
STEP
	move	#STEP_RTN,r5	;POINT TRACE ENTRY POINT TO STEP_RTN
GO
;
;	DO SINGLE STEP FOR TRACE COMMAND.  THIS WILL POINT THE
;	TRACE VECTOR BACK TO THE TRACE COMMAND AND EXECUTE 1 INSTRUCTION.
;	NOTE THAT THE PC IS IN R5
;
;	COPY THE REGISTERS FROM THE CURRENT WORKING SET TO THE
;	OLD REGISTER AREA.  AFTER RETURNING FROM THE GO COMMAND,
;	IT IS POSSIBLE TO SEE WHAT REGISTERS HAVE CHANGED
;
	ori	#DISABLE_IPL_2,mr
	move	#REGVAL,r0	;POINT TO CURRENT REGISTERS
	move	#REGOLD,r1	;OLD REGISTER SAVE AREA
	do	#NUMREG,_E1	;COPY REGISTERS
	movem	p:(r0)+,a		;GET REGISTER
	movem	a1,p:(r1)+	;SAVE IT
_E1
	move	#>OP_JSR,y0	;GET "JSR"
	movem	y0,p:TRACE	;SAVE IN TRACE VECTOR
	movem	r5,p:TRACE+1	;SAVE TRACE ROUTINE VECTOR
;
;	CONTINUE TRACING.  THIS POINT IS ENTERED IF WE TRACED AN INSTRUCTION
;	BUT THERE ARE MORE TO TRACE.  THIS CONTINUES THE TRACE OPERATION
;	WITH THE TRACE VECTOR STILL POINTING TO THE TRACE COMMAND
;
PRO2
	movem	p:USR_SR,x0
	bset	#13,x0		;set "T" bit in user sr
	movem	x0,p:USR_SR
;
;	THIS IS A TEMPORARY FIX BECAUSE OF THE "2B38EXXXX" MASK PROBLEM.
;	THIS WILL MAKE THE USER'S IPR ZERO ONLY WHEN TRACING.
;
	movem	p:USR_IPR,x0	;GET USER'S IPR
	movem	x0,p:IPR_TEMP	;SAVE IPR
	clr	a		;GET A ZERO
	movem	a,p:USR_IPR	;PUT A 0 IN USER'S IPR
;	;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;END OF BUG FIXES
	jmp	RESTORE_USER	;GO RESTORE REGISTERS AND TRACE 1 INSTRUCTION

;
;	STEP_GO - ENTRY POINT IF PROCEEDING FROM A BREAKPOINT (SWI)
;			
STEP_GO
	SAVE_USER			;SAVE THE USER STATE
;
;	THIS IS A FIX BECAUSE OF THE DSP "2B38EXXXX" MASK PROBLEM
;	IF THE USER CHANGED HIS IPR, THEN KEEP THE CURRENT VALUE THAT
;	THE USER SET. IF THE IPR DID NOT CHANGE (IT IS STILL ZERO) THEN
;	RESTORE THE PREVIOUS VALUE.  A PROBLEM WITH THIS BUG FIX IS THAT
;	THE USER CAN NOT TRACE CODE THAT SETS THE IPR TO ZERO.
;
	movem	p:USR_IPR,a	;GET USER'S IPR
	tst	a		;SEE IF ZERO
	jne	_CHANGED		;NO, IT CHANGED
	movem	p:IPR_TEMP,x0	;GET THE SAVED USER'S IPR
	movem	x0,p:USR_IPR	;PUT IT BACK IN THE REGISTER BLOCK
_CHANGED
;	;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;END OF BUG FIXES
	movem	p:USR_SR,x0
	bclr	#13,x0		;clear "T" bit in user sr
	movem	x0,p:USR_SR

;
;	REPLACE THE USER'S OPCODES WITH SWI'S.  SAVE THE ACTUAL OPCODE
;	IN A TABLE. WHEN THE SWI VECTOR IS TAKEN, THE SWI'S ARE REPLACED
;	WITH THE ACTUAL OPCODES.
;
	move	#>OP_SWI,y0	;LOAD "SWI"
	move	#BPLOC,r0		;TABLE OF BREAK POINT ADDRESSES
	move	#OPSAVE,r4	;TABLE OF ACTUAL OPCODES
	do	#NUMBRK,_L1	;REPLACE OPCODES WITH SWI'S
	movem	p:(r0),a		;GET ADDRESS
	tst	a	a1,r1	;SEE IF ZERO, PUT IN ADDRESS REG FOR INDEXING
	jeq	_L2		;YES, NO BREAKPOINT
	movem	p:(r1),y1		;GET OLD OPCODE 
	movem	y1,p:(r4)		;SAVE OPCODE
	movem	y0,p:(r1)		;REPLACE USER OPCODE WITH SWI
_L2
	move	x:(r0)+,x0	y:(r4)+,y1	;SHIFT POINTERS
_L1
;
;
;
;	SET VECTOR FOR SWI TO IMPLEMENT BREAKPOINTS
;
	clr	a	#OP_JSR,y0	;GET A "JSR"
	movem	a,p:TRACE		;NOP OUT THE TRACE INTERRUPT VECTOR
	movem	a,p:TRACE+1
	movem	y0,p:NMI		;SET UP NMI VECTOR
	move	#NMIENT,y0	;GET MONITOR NMI ENTRY POINT
	movem	y0,p:NMI+1	;SAVE IT IN VECTOR TABLE
	
	bclr	#HF2,x:HCR	;clear HF2 to signal host we're not debugging
;
;
;
;	RESTORE THE USER'S STACK AND REGISTERS. 
;	IF THE CALL COMMAND IS BEING USED,
;	THEN PUSH A RETURN TO MONITOR ADDRESS ON THE STACK ALSO
;	(TO BE EXECUTED BY THE USER'S RTS).
;
RESTORE_USER
	move	#USR_HOST_RX,r0
	movem	p:USR_HOST_RX,x0
	movem	p:USR_HOST_RX+1,x1
	movem	x0,p:(r0)+
	movem	x1,p:(r0)+

	movem	p:USR_HOST_TX,x0
	movem	p:USR_HOST_TX+1,x1
	movem	x0,p:(r0)+
	movem	x1,p:(r0)+
	
	movec	#0,sp		;RESET STACK POINTER
	movem	p:USR_SP,a	;NUMBER OF USER STACK ENTRIES
	move	#USTK+29,r0	;END OF USER SAVED STACK-1
	clr	b	#>$000001,x0
	move	#<15,b1
_not_yet_full	
	sub	x0,a		;DECREMENT NUMBER OF VALUES TO LOAD
	jlt	_full		;DONE LOADING STACK
	movem	p:(r0)-,ssh	;LOAD DATA ON STACK
	movem	p:(r0)-,ssl	;LOAD LOW VALUE ON STACK
	sub	x0,b
	jgt	_not_yet_full
_full
;
;	RESTORE THE USER'S REGISTERS AND PUSH ONTO THE STACK THE 
;	USER'S STACK PC AND STATUS REGISTER.  THEN DO AN RTI TO EXECUTE
;	THE USER'S CODE
;

	move	#USR_R1,r0
	nop
	movem	p:(r0)+,r1
	movem	p:(r0)+,r2
	movem	p:(r0)+,r3
	movem	p:(r0)+,r4
	movem	p:(r0)+,r5
	movem	p:(r0)+,r6
	movem	p:(r0)+,r7
	movem	p:(r0)+,n0
	movem	p:(r0)+,n1
	movem	p:(r0)+,n2
	movem	p:(r0)+,n3
	movem	p:(r0)+,n4
	movem	p:(r0)+,n5
	movem	p:(r0)+,n6
	movem	p:(r0)+,n7
	move	  (r0)+		;skip over USR_M0
	movem	p:(r0)+,m1
	movem	p:(r0)+,m2
	movem	p:(r0)+,m3
	movem	p:(r0)+,m4
	movem	p:(r0)+,m5
	movem	p:(r0)+,m6
	movem	p:(r0)+,m7
	movem	p:(r0)+,x0
	movem	p:(r0)+,x1
	movem	p:(r0)+,y0
	movem	p:(r0)+,y1
	movem	p:(r0)+,a2
	movem	p:(r0)+,a1
	movem	p:(r0)+,a0
	movem	p:(r0)+,b2
	movem	p:(r0)+,b1
	movem	p:(r0)+,b0
	movem	p:(r0)+,ssh	;set user return pc
	movem	p:(r0)+,ssl	;set user return sr
	movem	p:(r0)+,omr
	movem	p:(r0)+,la
	movem	p:(r0)+,lc
	move	  (r0)+		;skip over USR_SP
	movep	p:(r0)+,x:BCR	;set user BCR
	movep	p:(r0)+,x:IPR	;set user IPR

	movem	p:USR_R0,r0
	movem	p:USR_M0,m0

	rti			;RETURN TO EXECUTE USERS CODE



;	PAGE

;
;	SAVE THE USER'S CONTEXT AFTER AN INTERRUPT. BY THE TIME WE GET HERE,
;	THE USER'S R0 AND R1 HAVE ALREADY BEEN SAVED.  R0 HAS THE USER'S SR
;	FROM THE INTERRUPT AND R1 HAS THE PC.
;
SAVE_CONTEXT
	movem	r2,p:USR_R2
	movem	m2,p:USR_M2
	move	#USR_R3,r2
	movec	#$FFFF,m2
	ori	#DISABLE_IPL_2,mr	;NO SCALING, SET IPL TO 3
	movem	r3,p:(r2)+
	movem	r4,p:(r2)+
	movem	r5,p:(r2)+
	movem	r6,p:(r2)+
	movem	r7,p:(r2)+
	movem	n0,p:(r2)+
	movem	n1,p:(r2)+
	movem	n2,p:(r2)+
	movem	n3,p:(r2)+
	movem	n4,p:(r2)+
	movem	n5,p:(r2)+
	movem	n6,p:(r2)+
	movem	n7,p:(r2)+
	movem	m0,p:(r2)+
	movem	m1,p:(r2)+
	move	     (r2)+	;skip over USR_M2
	movem	m3,p:(r2)+
	movem	m4,p:(r2)+
	movem	m5,p:(r2)+
	movem	m6,p:(r2)+
	movem	m7,p:(r2)+
	movem	x0,p:(r2)+
	movem	x1,p:(r2)+
	movem	y0,p:(r2)+
	movem	y1,p:(r2)+
	movem	a2,p:(r2)+
	movem	a1,p:(r2)+
	movem	a0,p:(r2)+
	movem	b2,p:(r2)+
	movem	b1,p:(r2)+
	movem	b0,p:(r2)+
	movem	r1,p:(r2)+	;SAVE USER'S PC
	movem	r0,p:(r2)+	;SAVE USER'S SR
	movec	ssl,r0		;GET THE CALLER'S SR
	movec	ssh,r1		;GET THE CALLER'S PC
	movem	omr,p:(r2)+
	movem	la,p:(r2)+
	movem	lc,p:(r2)+
	movem	sp,p:(r2)+	;STACK POINTER
	movep	x:BCR,p:(r2)+	;GET USER BCR
	movep	x:IPR,p:(r2)+	;GET INTERRUPT PRIORITY REGISTER
	movep	#DSP_BCR,x:BCR	;SET DSP BCR
	
;
;	SET FOR LINEAR ADDRESSING
;
	movec	m2,m0
	movec	m2,m1
	movec	m2,m3				
	movec	m2,m4					
	movec	m2,m5
	movec	m2,m6
	movec	m2,m7



;
;	SAVE THE USER'S STACK
;
	move	#USTK+30,r4	;GET END OF USER STACK AREA
	movem	p:USR_SP,n4	;GET NUMBER OF STACK ENTRIES
	clr	b	#>$000001,x0
	move	#<15,b1
	move	(r4)-n4		;BACK UP POINTER
	move	(r4)-n4		;2 ENTRIES/STACK ELEMENT
_stack_not_empty	
	movec	sp,a		;GET THE USER STACK POINTER
	tst	a		;SEE IF IT IS ZERO (EMPTY)
	jeq	_stack_empty	;YES, JUMP OUT
	movem	ssl,p:(r4)+	;SAVE LOW PART OF STACK
	movem	ssh,p:(r4)+	;SAVE HIGH PART AND DEC SP
	sub	x0,b
	jgt	_stack_not_empty
_stack_empty


;
;	RESTORE THE PC OF THE SUBROUTINE THAT CALLED US
;         This doesnt work on linux !!!! ( bug in the assembler ?? )
;         Fixed it with a bad hack, see later

	movec	#0,sp		;RESET STACK POINTER
	movec	r1,ssh		;RESTORE CALLER'S PC
	movec	r0,ssl		;RESTORE CALLER'S SR


;
;	NOW THAT THE CALLER'S INFO ON THE STACK IS RESTORED,
;	RETURN TO THE CALLER
;
	move	#USR_HOST_RX,r2
	movem	p:HOST_RX,x0
	movem	p:HOST_RX+1,x1
	movem	x0,p:(r2)+
	movem	x1,p:(r2)+

	movem	p:HOST_TX,x0
	movem	p:HOST_TX+1,x1
	movem	x0,p:(r2)+
	movem	x1,p:(r2)+

	rts


;	PAGE

;	ENTRY POINT FOR BREAKPOINTS
;
SWIENT
;
;
;	quick breakpoint countdown by r b-j
;
;
	ori	#DISABLE_IPL_2,mr
	movem	x0,p:USR_X0	;quick save context
	movem	a2,p:USR_A2
	movem	a1,p:USR_A1
	movem	a0,p:USR_A0
;
;	check to see if the required number of breakpoints have been
;	taken before stopping
;
	movem	p:NBRCT,a		;get breakpoint count
	move	#>1,x0		;get a one
	sub	x0,a		;decrement count
	jeq	do_break		;count is zero, so do breakpoint
;
	movem	a,p:NBRCT		;save new breakpoint count
	movec	ssh,a		;get user pc
	sub	x0,a		;back up to swi
	movec	a,ssh		;put back to user pc
	movem	p:BPLOC,x0	;get address of only breakpoint
	cmp	x0,a		;check if this is it
	jne	do_break		;if not, must be user swi
	movem	r0,p:USR_R0	;save r0
	move	a,r0		;point to breakpoint
	movem	p:OPSAVE,a	;get opcode at only bp
	movem	a,p:(r0)		;restore opcode
	movec	ssl,x0		;get user sr
	bset	#13,x0		;set trace bit
	movec	x0,ssl		;put back to user sr
	move	#tr_rtn,r0
	move	#OP_JSR,x0	;get "jsr"
	movem	x0,p:TRACE	;save in trace vector
	movem	r0,p:(TRACE+1)	;save trace routine vector
	movem	p:USR_R0,r0	;restore everything
	movem	p:USR_X0,x0
	movem	p:USR_A2,a2
	movem	p:USR_A1,a1
	movem	p:USR_A0,a0
	rti			;trace instruction at bp
tr_rtn
	movem	x0,p:USR_X0
	movem	r0,p:USR_R0
	move	#OP_NOP,x0	;nop out trace vector
	movem	x0,p:TRACE	;save in trace vector
	movem	x0,p:(TRACE+1)	;save trace routine vector
	movem	p:BPLOC,r0	;get user pc
	move	#>OP_SWI,x0
	movem	x0,p:(r0)		;put back breakpoint
	movec	ssl,x0		;get user sr
	bclr	#13,x0		;clear trace bit
	movec	x0,ssl		;put back to user sr
	movem	p:USR_X0,x0
	movem	p:USR_R0,r0
	rti			;back to user
;
do_break
	movem	p:USR_X0,x0	;restore context for SAVE_USE's sake
	movem	p:USR_A2,a2
	movem	p:USR_A1,a1
	movem	p:USR_A0,a0
;
;
;
;
	SAVE_USER			;SAVE USER STATE
;
;
;	SEE IF BREAKPOINT OCCURRED AT LA OF A LOOP
;
	movem	p:USR_SP,n0	;GET USER STACK POINTER
	move	#USTK+31,r0	;POINT TO END OF STACK AREA+1
	move	#>1,x0		;get a one
	movem	p:USR_PC,a	;get user pc
	sub	x0,a	(r0)-n0	;point pc back to were pc stopped
	move		(r0)-n0	;BACK UP TO SSH 
	movem	p:(r0),b		;GET SSH
	sub	x0,b		;BACK IT UP ONE
	cmp	a,b		;SEE IF BREAK WAS AT LA
	jne	_NOTLA		;NO
	movem	p:USR_LA,a	;GET LA
	movem	p:USR_LC,b	;GET THE LOOP COUNTER
	add	x0,b		;INCREMENT IT
	movem	b,p:USR_LC	;SAVE NEW LOOP COUNTER
_NOTLA
	movem	a,p:USR_PC	;save corrected pc
	jmp	CMD



;	PAGE
;
;	STEP_RTN - ENTRY POINT IF USING THE TRACE COMMAND
;
STEP_RTN
	SAVE_USER		

;SAVE USER STATE
;
;	THIS IS A FIX BECAUSE OF THE DSP 2B38EXXXX MASK PROBLEM
;	IF THE USER CHANGED HIS IPR, THEN KEEP THE CURRENT VALUE THAT
;	THE USER SET. IF THE IPR DID NOT CHANGE (IT IS STILL ZERO) THEN
;	RESTORE THE PREVIOUS VALUE.  A PROBLEM WITH THIS BUG FIX IS THAT
;	THE USER CAN NOT TRACE CODE THAT SETS THE IPR TO ZERO.
;
	movem	p:USR_IPR,a	;GET USER'S IPR
	tst	a		;SEE IF ZERO
	jne	CHANGED		;NO, IT CHANGED
	movem	p:IPR_TEMP,x0	;GET THE SAVED USER'S IPR
	movem	x0,p:USR_IPR	;PUT IT BACK IN THE REGISTER BLOCK
CHANGED
;	;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;END OF BUG FIXES
	movem	p:USR_SR,x0
	bclr	#13,x0		;clear "T" bit in user sr
	movem	x0,p:USR_SR
;
;	CHECK TO SEE IF WE ARE DONE TRACING (CHECK THE TRACE COUNT)
;
	move	#>1,x0		;GET A 1
	movem	p:NUMTR,a		;GET NUMBER OF INSTRUCTIONS TO TRACE
	sub	x0,a		;DECREMENT NUMBER OF INSTRUCTIONS TO TRACE
	jeq	STEP_CMD		;ALL DONE, GO TO COMMAND LEVEL
	movem	a1,p:NUMTR	;SAVE NEW COUNT
	jmp	PRO2		;DO ANOTHER TRACE


;	PAGE
;
;	ENTRY POINT FOR USER GENERATED NMI INTERRUPT.
;	THIS INTERRUPT IS GENERATED BY PUTTING +10 VOLTS ON IRQB.
;
NMIENT
	SAVE_USER			;SAVE THE USER'S STATE
				;DROP TO COMMAND LEVEL
	



CMD
;
;	RESTORE THE USER'S OPCODES.  THIS WILL SCAN THE BREAKPOINT TABLE
;	AND IF THERE IS A BREAKPOINT, THE OPCODE FROM THE TABLE WILL BE
;	PUT BACK INTO THE USER'S CODE.
;

	move	#BPLOC,r0		;TABLE OF BREAK POINT ADDRESSES
	move	#OPSAVE,r4	;TABLE OF ACTUAL OPCODES
	do	#NUMBRK,L1	;REPLACE OPCODES
	movem	p:(r0),a		;GET ADDRESS
	tst	a		;SEE IF ZERO
	jeq	L2		;YES, NO BREAKPOINT
	move	a1,r1		;PUT IN ADDRESS REG FOR INDEXING
	movem	p:(r4),y1		;GET OPCODE FROM TABLE
	movem	y1,p:(r1)		;REPLACE USER'S OPCODE
L2
	move	x:(r0)+,x0	y:(r4)+,y1	;SHIFT POINTERS
L1	
STEP_CMD
;
	move	#STEP_GO,r5	;ENTRY POINT FOR TRACE IF PROCEEDING FROM SWI
	move	#>OP_JMP,x0
	move	#>GO,x1
	movem	x0,p:NMI
	movem	x1,p:NMI+1
	move	#>STEP,x1
	movem	x0,p:TRACE
	movem	x1,p:TRACE+1
	
	bset	#HF2,x:HCR	;set HF2 to signal host we're debugging
	movep	#DSP_IPR,x:IPR	
	andi	#DISABLE_IPL_1,mr	;enable host interrupts
hang
	jmp	hang		;loop forever

	org	p:REGBASE-2
STACKENT				;STACK OVERFLOW ERROR HANDLER, must be 2 words!
	jmp	>NMIENT		;MUST jump to error handling code
				;PUT NO FURTHER CODE HERE!

;	PAGE


NUMREG	equ	42
NUMBRK	equ	10		;NUMBER OF BREAKPOINTS

DSP_BCR	equ	$3333		;BCR FOR MONITOR
DSP_IPR	equ	HOST_IPL_2	;IPR FOR MONITOR


REGVAL				;REGISTER STORAGE

USR_R0	dc	0
USR_R1	dc	0
USR_R2	dc	0
USR_R3	dc	0
USR_R4	dc	0
USR_R5	dc	0
USR_R6	dc	0
USR_R7	dc	0
USR_N0	dc	0
USR_N1	dc	0
USR_N2	dc	0
USR_N3	dc	0
USR_N4	dc	0
USR_N5	dc	0
USR_N6	dc	0
USR_N7	dc	0
USR_M0	dc	$FFFF
USR_M1	dc	$FFFF
USR_M2	dc	$FFFF
USR_M3	dc	$FFFF
USR_M4	dc	$FFFF
USR_M5	dc	$FFFF
USR_M6	dc	$FFFF
USR_M7	dc	$FFFF
USR_X0	dc	0
USR_X1	dc	0
USR_Y0	dc	0
USR_Y1	dc	0
USR_A2	dc	0
USR_A1	dc	0
USR_A0	dc	0
USR_B2	dc	0
USR_B1	dc	0
USR_B0	dc	0
USR_PC	dc	0
USR_SR	dc	0
USR_OMR	dc	0
USR_LA	dc	0
USR_LC	dc	0
USR_SP	dc	0
USR_BCR	dc	0
USR_IPR	dc	0

REGOLD				;OLD REGISTERS
;	dup	16
;	dc	0
;	endm
	dc	0
	dc	0
	dc	0
	dc	0

	dc	0
	dc	0
	dc	0
	dc	0

	dc	0
	dc	0
	dc	0
	dc	0

	dc	0
	dc	0
	dc	0
	dc	0

;	dup	8
;	dc	$FFFF		;init the M registers
;	endm

	dc	$FFFF
	dc	$FFFF
	dc	$FFFF
	dc	$FFFF

	dc	$FFFF
	dc	$FFFF
	dc	$FFFF
	dc	$FFFF

;	dup	NUMREG-24
;	dc	0
;	endm

	dc	0
	dc	0
	dc	0
	dc	0

	dc	0
	dc	0
	dc	0
	dc	0

	dc	0
	dc	0
	dc	0
	dc	0

	dc	0
	dc	0
	dc	0
	dc	0

	dc	0
	dc	0

BPLOC				;BREAK POINT LOCATION TABLE
;	dup	NUMBRK
;	dc	0
;	endm

	dc	0
	dc	0
	dc	0
	dc	0
	dc	0
	dc	0
	dc	0
	dc	0
	dc	0
	dc	0

OPSAVE				;USERS ACTUAL OPCODES
;	dup	NUMBRK
;	dc	0
;	endm

	dc	0
	dc	0
	dc	0
	dc	0
	dc	0
	dc	0
	dc	0
	dc	0
	dc	0
	dc	0

USTK				;USER'S STACK
;	dup	30
;	dc	0
;	endm

	dc	0
	dc	0
	dc	0
	dc	0
	dc	0
	dc	0
	dc	0
	dc	0
	dc	0
	dc	0

	dc	0
	dc	0
	dc	0
	dc	0
	dc	0
	dc	0
	dc	0
	dc	0
	dc	0
	dc	0

	dc	0
	dc	0
	dc	0
	dc	0
	dc	0
	dc	0
	dc	0
	dc	0
	dc	0
	dc	0

IPR_TEMP	dc	0	;TEMP FOR USER'S IPR BECAUSE OF DSP BUGS
NBRCT	dc	1		;THE COUNT OF NUMBER OF BREAKPOINTS HIT SO FAR
NUMTR	dc	1		;NUMBER OF INSTRUCTIONS TO TRACE

USR_HOST_RX	dc	0
		dc	0
USR_HOST_TX	dc	0
		dc	0

;           X1= 000000 X0= 000000  R7= 0000  N7= 0000  M7= FFFF
;           Y1= 000000 Y0= 000000  R6= 0000  N6= 0000  M6= FFFF
; A2= 00    A1= 000000 A0= 000000  R5= 0000  N5= 0000  M5= FFFF
; B2= 00    B1= 000000 B0= 000000  R4= 0000  N4= 0000  M4= FFFF
;                                  R3= 0000  N3= 0000  M3= FFFF
; PC=*0040  SR= 0300  OMR= 02      R2= 0000  N2= 0000  M2= FFFF
; LA= 0000  LC= 0000   SP= 00      R1= 0000  N1= 0000  M1= FFFF
;          BCR= 0000  IPR= 000000  R0= 0000  N0= 0000  M0= FFFF


	END

