/****************************************************************************************
*											*
*			maas.c                                                      *
*										 	*
*			Scans ####.lod files from the Motorola DSP56xxxCLASA
*			development system and loads any boot code into the
*			MAAS board.				
*										
*			Also provides pci-host port communications ultilities:	
*				boot_dsp()					
*				load_dsp_application()				
*				set_dsp_write_ptr()				
*				set_dsp_read_ptr()				
*				write_dsp_data()				
*				read_dsp_data()					
*										
*										
*										
****************************************************************************************/
#ifdef __linux__
#include<asm/io.h>
#include <math.h>
#define inp(x) inb(x)
#define outp(x,y) outb(y,x)
#endif

#include "../maaslib/maaslib.h"
#include "dissas/util56k.h"
#include "maas.h"



#ifdef HASH_BY_NAME
symbol_entry symbol_hash_by_name_table[SYMBOL_TABLE_SIZE];
#endif
symbol_entry symbol_hash_by_addr_table[SYMBOL_TABLE_SIZE][(eNullSpace+1)];

char symbol_names[SYMBOL_TABLE_SIZE][20];

int symbol_name_index;


int host_command(register unsigned int cmd)
{
  register int timeout;
  

  /* if in  HCTR TWSD is cleared, if Host command is pending
     therewill be a wait of max 8 waitstates until pci target termination
     is made and disconnect-Cretry is signaled */
  
	
  /* so better lets see if ther is a host command pending and wait */

  for (timeout=TIMEOUT; timeout-- > 0 && (maas_r_hcvr() & HCVR_HC););
  if (timeout == 0)
    {
      (void) fprintf(stderr, "DSP_HC_TIMEOUT: Hosct command Pending\n");
      return DSP_HC_TIMEOUT;
    }
  /* write command vector with HC set */

  /* set host command bit */
  maas_w_hcvr(cmd & HCVR_HC);
  
  /* wait until host command is serviced */
  for (timeout=TIMEOUT; timeout-- > 0 && (maas_r_hcvr() & HCVR_HC););
  if (timeout == 0)
    {
      (void) fprintf(stderr, "DSP_HC_TIMEOUT\n");
      return DSP_HC_TIMEOUT;
    }
  return 0;
}


int set_dsp_read_write_ptr(register int mode_plus_ptr)
{
  register int timeout;

  if (mode_plus_ptr >= 0){ /* ????? */	  

    /* wait until transmit fifo is emmpty and tramitter ready */
    timeout = TIMEOUT;
    while((timeout-- > 0) 
	  && (maas_r_hstr() &(HSTR_HTRQ+HSTR_TRDY)) != (HSTR_HTRQ+HSTR_TRDY));

    if (timeout == 0){
      (void) fprintf(stderr, "DSP_WRITE_TIMEOUT 0:not ready\n");
      return DSP_WRITE_TIMEOUT;
    }

    /* send hostcommand set pointer host ???? */
    host_command(SET_PTR_HOST_CMD);

    /* wait again to the same ??? */
    timeout = TIMEOUT;
    while((timeout-- > 0) 
	  && (maas_r_hstr() &(HSTR_HTRQ+HSTR_TRDY)) != (HSTR_HTRQ+HSTR_TRDY));

    if (timeout == 0){
      (void) fprintf(stderr, "DSP_WRITE_TIMEOUT dont happen\n");
      return DSP_WRITE_TIMEOUT;
    }
    
    /* write ??? */
    maas_w_data(mode_plus_ptr);

    if (!(mode_plus_ptr & WRITE_DSP)){

      timeout = TIMEOUT;
      while ((timeout-->0) 
	     && ((maas_r_hstr() & (HSTR_HTRQ & HSTR_HF3 )) != (HSTR_HTRQ & HSTR_HF3)));

      if (timeout == 0){
	(void) fprintf(stderr, "DSP_READ_TIMEOUT 0\n");
	return DSP_READ_TIMEOUT;
      }
      

      /*  dummy read to clear out fifo buffer.  next word is good. */
      while(maas_r_hstr() & HSTR_HRRQ)
	maas_r_data();

    }
    return 0;
  }
  else{
    (void) fprintf(stderr, "improper DSP r/w address: $%08x\n", mode_plus_ptr);
    return -1;
  }
} /* set_dsp_read_write_ptr */



int write_dsp_data(register int data)

{
  register int timeout;

  timeout = TIMEOUT;    
  while((timeout-- > 0) 
	&& (maas_r_hstr() &(HSTR_HTRQ+HSTR_TRDY)) !=(HSTR_HTRQ+HSTR_TRDY) );

  if (timeout == 0){
    (void) fprintf(stderr, "DSP_WRITE_TIMEOUT\n");
    return DSP_WRITE_TIMEOUT;
  }

  maas_w_data(data);

  return 0;
}


int read_dsp_data(int *data_ptr)

{
  register int timeout, data;

  timeout = TIMEOUT;
  while ((timeout-- >0) 
	 && ((maas_r_hstr() & (HSTR_HTRQ & HSTR_HF3 )) != (HSTR_HTRQ & HSTR_HF3)));

  if (timeout == 0){
    (void) fprintf(stderr, "DSP_READ_TIMEOUT\n");
    return DSP_READ_TIMEOUT;
  }

  data = maas_r_data();

  if (data < 0x00800000L)
    *data_ptr = data;
  else
    *data_ptr = data - 0x01000000L;		/* sign extend a negative number */

  return 0;
}


int hash_symbol(char *symbol_name)
{
  register int i, hash;
	
  hash = 0;
  i = 0;
  while (symbol_name[i]!='\0' && i<19){

    hash += (int)(symbol_name[i++]);
  }

  hash &= (SYMBOL_TABLE_SIZE-1);

  i = 0;
  while ( (symbol_hash_by_name_table[hash].address<0 
	   || strcmp(symbol_hash_by_name_table[hash].name, symbol_name) !=0) 
	  && i < SYMBOL_TABLE_SIZE){

    hash++;
    hash &= (SYMBOL_TABLE_SIZE-1);
    i++;
  }
  if (i < SYMBOL_TABLE_SIZE){

    return symbol_hash_by_name_table[hash].address;
  }
  else{
    (void) fprintf (stderr, "label '%s' not found. \n", symbol_name);
    return -1;
  }
}


int get_long(void)
{
  int value;
  (void) read_dsp_data(&value);
  return value;
}

int read_long(char *symbol_name)
{
  int value;
  get_at_label(symbol_name, 0);
  (void) read_dsp_data(&value);
  return value;
}

void write_long(char *symbol_name, int value)
{
  put_at_label(symbol_name, 0);
  put_long(value);
}


double get_double(void)
{
  int value;
  (void) read_dsp_data(&value);
  return (double)value*(1.0/8388608.0);
}

void put_double(double value)
{
  if (value > 0.99999988079071)
    value = 0.99999988079071;
  else if (value < -1.0)
    value = -1.0;
  (void) write_dsp_data( (int)floor(8388608.0*value + 0.5) );
}

double read_double(char *symbol_name)
{
  int value;
  get_at_label(symbol_name, 0);
  (void) read_dsp_data(&value);
  return (double)value*(1.0/8388608.0);
}

void write_double(char *symbol_name, double value)
{
  put_at_label(symbol_name, 0);
  if (value > 0.99999988079071)
    value = 0.99999988079071;
  else if (value < -1.0)
    value = -1.0;
  (void) write_dsp_data( (int)floor(8388608.0*value + 0.5) );
}

void set_input_pot_level(double dBr_left, double dBr_right)
{
  int left_level, right_level;
  
  left_level  =  (int)floor(41.0*exp(-0.115129254*dBr_left ) + 0.5);
  if ( left_level > 255)
    left_level = 255;
  right_level  =  (int)floor(41.0*exp(-0.115129254*dBr_right) + 0.5);
  if (right_level > 255)
    right_level = 255;
  (void)set_dsp_read_write_ptr(READ_DSP);  /* NOP out DSP read from host */
  
  (void) write_dsp_data( (left_level<<16) + (right_level<<8) );

  (void) host_command(SET_INPUT_GAIN_HOST_CMD);
}


void set_aux_pot_level(double dBr_left, double dBr_right)
{
  int left_level, right_level;
  
  left_level  =  (int)floor(107.0*exp(-0.115129254*dBr_left ) + 0.5);

  if ( left_level > 255)
    left_level = 255;

  right_level  =  (int)floor(107.0*exp(-0.115129254*dBr_right) + 0.5);

  if (right_level > 255)
    right_level = 255;

  (void)set_dsp_read_write_ptr(READ_DSP);  /* NOP out DSP read from host */
  
  (void) write_dsp_data( (left_level<<16) + (right_level<<8) );

  (void) host_command(SET_AUX_GAIN_HOST_CMD);
}


void boot_dsp(char *boot_file)
{

  FILE *input;
  int op, input_size;
  unsigned int pc=0,pcnew;
  register int i;
  register char *input_ptr;
  char *buffer_end, *input_buffer, op_str[8];
  int bootcode[512];
  char mode;
  short bootflag;
  int mem_space;
  int timeout;

  op_str[6] = '\0';
  bootflag = 0;

  for (i=0; i<512; i++)
    bootcode[i] = NOP;

  if ((input_buffer = (char *)malloc(10001)) == NULL){
    (void) fprintf(stderr, "boot_dsp() malloc error.\n");
  }

  if ((input = fopen(boot_file, "r")) == NULL){
    (void) fprintf(stderr, "unable to open DSP boot file: %s\n", boot_file);
  }
	
  input_size = fread(input_buffer, 1, 10000, input);

  fclose(input);

  if ( input_size> 0) {
    input_ptr = input_buffer;
    buffer_end = input_buffer + (int)input_size;
    mode = OTHER;

    while (input_ptr<buffer_end && isspace(*input_ptr))
      input_ptr++;
      
    while (input_ptr < buffer_end){
	  
      if (*input_ptr == '_'){
	if (strncmp(input_ptr, "_DATA P", 7) == 0)
	  {
	    input_ptr += 7;
	    while (input_ptr<buffer_end && isspace(*input_ptr))
	      input_ptr++;
	    sscanf(input_ptr, "%4x", &pcnew);
					
	    if (pcnew == 0)
	      bootflag = 1;
					
	    /* This is a bad hack, so that all code that will
	       be loded into higher memory can be appended to the
	       original boot code and moved afterwards. I don't know 
	       how this is managed with the original assembler under 
	       dos, but under linux with the PD assembler it 
	       didn't work  */

	    if (pcnew < 0x200)   /* bootcode */
	      pc = pcnew;
		  
	    /* else leave pc unchanged and append code to 
	       current position  */
		  
	    mode = 'P';
	  }
	else
	  mode = OTHER;
	      
	while (input_ptr<buffer_end && *input_ptr!='\n')
	  input_ptr++;
	while (input_ptr<buffer_end && isspace(*input_ptr))
	  input_ptr++;
      }
	  
      switch (mode)
	{
	case OTHER:
	  while (input_ptr<buffer_end && (*input_ptr!='_' || *(input_ptr-1)!='\n'))
	    input_ptr++;
	  break;
	  
	case 'P':
	  for (i=0; i<6; i++)
	    op_str[i] = *input_ptr++;
	      
	  sscanf(op_str, "%6x", &op);

	  while (input_ptr<buffer_end && isspace(*input_ptr))
	    input_ptr++;
	      
	  if (pc < 0x200) 
	    bootcode[(int)(pc++)] = op;
	  break;
	}
			
      while (input_ptr<buffer_end && isspace(*input_ptr))
	input_ptr++;
    }

    for (i=0; i<SYMBOL_TABLE_SIZE; i++)
      {
	symbol_names[i][0] = '\0';
      }
    symbol_name_index = 0;
		
#ifdef HASH_BY_NAME
    for (i=0; i<SYMBOL_TABLE_SIZE; i++)
      {
	symbol_hash_by_name_table[i].name = NULL;
	symbol_hash_by_name_table[i].address = -1L;
      }
#endif
    for (mem_space=eXSpace; mem_space<=eNullSpace; mem_space++)
      {
	for (i=0; i<SYMBOL_TABLE_SIZE; i++)
	  {
	    symbol_hash_by_addr_table[i][mem_space].name = NULL;
	    symbol_hash_by_addr_table[i][mem_space].address = -1L;
	  }
      }

    if (bootflag)
      {


	/* reset 56301 */
	maas_w_hcvr(HCVR_HNMI|HCVR_HC);

			/* wait one tick */
	for (i=0; i<10000; i++);
	for (timeout=TIMEOUT; (timeout-- > 0) && ((maas_r_hcvr() & HCVR_HC)==HCVR_HC); );
	    
	if(timeout == 0){
	  fprintf(stderr,"boot_dsp: dsp doesnot return from reset\n");
	  return;
	}
	
	/* set controls to take least significant 24-Bit of int */
	/* HCTR_SFT = 0, HCTR_HTF1=0, HCTR_HTF0=1,HCTR_HRF1=0, HCTR_HRF0=1,
	   HCTR_HF0-2 =0, HCTR_TWSD=0 */
	maas_w_hctr(HCTR_HTF0|HCTR_HRF0);


			/* wait one tick */
	for (i=0; i<10000; i++);

	fprintf(stderr,"Loading boot programm %s...",boot_file);
	for (i=0; i<512; i++)	/* load program */
	  {
	    write_dsp_data(bootcode[i]);
	  }
	fprintf(stderr," done \n");
      }
    }
  else
    {
      (void) fprintf (stderr, "boot file read error. \n");
    }
  
  free(input_buffer);
  
}



void load_dsp_application(char *app_file)

{
  FILE *input;
  int op, input_size;
  unsigned int pc, mem_space = 0, mem_address;
  register int i, hash;
  register char *input_ptr;
  char *buffer_end, *input_buffer, op_str[8];
  char mode;
  char symbol_name[20];
	
  op_str[6] = '\0';
	
	
  if ((input_buffer = (char *)malloc(32767)) == NULL)
    {
      (void) fprintf(stderr, "load_dsp_application() malloc error.\n");
      return;
    }

  if ((input = fopen(app_file, "r")) == NULL)
    {
      (void) fprintf(stderr, "unable to open application file: %s \n", app_file);
      return;
    }

  input_size = fread(input_buffer, 1, 32767, input);
	
  fclose(input);
  
  if ( input_size> 0)
    {
      set_dsp_write_ptr(P, process_stereo_chunk);
      write_dsp_data(RTI);


      input_ptr = input_buffer;
      buffer_end = input_buffer + (int)input_size;
      mode = OTHER;

      while (input_ptr<buffer_end && isspace(*input_ptr))
	input_ptr++;

      while (input_ptr < buffer_end)
	{
	  if (*input_ptr == '_')
	    {
	      if (strncmp(input_ptr, "_DATA ", 6) == 0)
		{
		  input_ptr += 6;
		  mode = *input_ptr++;
		  
		  if (mode == 'P' || mode == 'X' || mode == 'Y')
		    {
		      while (input_ptr<buffer_end && isspace(*input_ptr))
			input_ptr++;
		      sscanf(input_ptr, "%4x", &pc);
		      if (mode == 'P')
			set_dsp_write_ptr(P, pc);
		      else if (mode == 'X')
			set_dsp_write_ptr(X, pc);
		      else if (mode == 'Y')
			set_dsp_write_ptr(Y, pc);
		    }
		  else
		    {
		      fprintf(stderr, "ERROR - unknown _DATA block type: %c\n", mode);
		      mode = OTHER;
		    }
		}
	      else if (strncmp(input_ptr, "_SYMBOL ", 8) == 0)
		{
		  input_ptr += 8;
		  mode = *input_ptr++;
		  
		  if (mode == 'P')
		    {
		      mem_space = ePSpace; 
		      mode = SYMBOL;
		    }
		  else if (mode == 'X')
		    {
		      mem_space = eXSpace; 
		      mode = SYMBOL;
		    }
		  else if (mode == 'Y')
		    {
		      mem_space = eYSpace; 
		      mode = SYMBOL;
		    }
		  else if (mode == 'L')
		    {
		      mem_space = eLSpace; 
		      mode = SYMBOL;
		    }
		  else if (mode == 'N')
		    {
		      mem_space = eNullSpace; 
		      mode = SYMBOL;
		    }
		  else
		    mode = OTHER;
		}
	      else
		mode = OTHER;

	      while (input_ptr<buffer_end && *input_ptr!='\n')
		input_ptr++;
	      while (input_ptr<buffer_end && isspace(*input_ptr))
		input_ptr++;
	    }
	  
	  switch (mode)
	    {
	    case SYMBOL:
	      i = 0;
	      while (!isspace(*input_ptr) && i<19)
		symbol_name[i++] = *(input_ptr++);
	      symbol_name[i] = '\0';
	      strcpy((char *)&(symbol_names[symbol_name_index][0]), (const char *)symbol_name);
	      while (strncmp(input_ptr, " I ", 3) != 0)
		input_ptr++;
	      input_ptr += 3;
	      sscanf(input_ptr, "%6x", &mem_address);
	      
	      mem_address &= 0x0000FFFF;
	      
#ifdef HASH_BY_NAME
	      hash = 0;
	      i = 0;
	      while (symbol_name[i] != '\0')
		hash += (int)symbol_name[i++];
	      hash &= (SYMBOL_TABLE_SIZE-1);
	      i = 0;
	      while ( symbol_hash_by_name_table[hash].address>=0 && i<SYMBOL_TABLE_SIZE )
		{
		  hash++;
		  hash &= (SYMBOL_TABLE_SIZE-1);
		  i++;
		}
	      if (i < SYMBOL_TABLE_SIZE)
		{
		  symbol_hash_by_name_table[hash].name = (char *)&(symbol_names[symbol_name_index][0]);
		  symbol_hash_by_name_table[hash].address = ((mem_space<<16) + mem_address)&0x007FFFFF;
		}
	      else
		fprintf (stderr, "symbol_hash_by_name_table full. \n");
#endif
	      hash = (mem_address + (mem_address/SYMBOL_TABLE_SIZE))&(SYMBOL_TABLE_SIZE-1);
	      i = 0;
	      while ( symbol_hash_by_addr_table[hash][mem_space&0x07].address>=0 && i<SYMBOL_TABLE_SIZE )
		{
		  hash++;
		  hash &= (SYMBOL_TABLE_SIZE-1);
		  i++;
		}
	      if (i < SYMBOL_TABLE_SIZE)
		{
		  symbol_hash_by_addr_table[hash][mem_space&0x07].name = (char *)&(symbol_names[symbol_name_index][0]);
		  symbol_hash_by_addr_table[hash][mem_space&0x07].address = ((mem_space<<16) + mem_address)&0x007FFFFF;
		}
	      else
		fprintf (stderr, "symbol_hash_by_addr_table full. \n");
	      
	      symbol_name_index++;
	      
	      while (input_ptr<buffer_end && *input_ptr!='\n')
		input_ptr++;
	      while (input_ptr<buffer_end && isspace(*input_ptr))
		input_ptr++;
	      break;
	      
	    case 'P':
	    case 'X':
	    case 'Y':
	      for (i=0; i<6; i++)
		op_str[i] = *input_ptr++;
	      
	      sscanf(op_str, "%6x", &op);
	      write_dsp_data(op);
	      pc++;
	      break;
	      
	    case OTHER:
	    default:
	      while (input_ptr<buffer_end && (*input_ptr!='_' || *(input_ptr-1)!='\n'))
		input_ptr++;
	      break;
	    }

	  while (input_ptr<buffer_end && isspace(*input_ptr))
	    input_ptr++;
	}
      
      set_dsp_write_ptr(P, process_stereo_chunk);
      write_dsp_data(NOP);
    }

  else
    {
      (void) fprintf (stderr, "application file read error. \n");
    }
  
  free(input_buffer);

  
  /* debug 
     (void) fprintf(stderr, "\n   #          SYMBOL name  address \n");
     for (i=0; i<SYMBOL_TABLE_SIZE; i++)
     {
     if (symbol_hash_by_name_table[i].address >= 0)
     (void) fprintf(stderr, "%4d %20s  %06lX \n", i, symbol_hash_by_name_table[i].name, symbol_hash_by_name_table[i].address);
     }

     for (mem_space=eXSpace; mem_space<=eNullSpace; mem_space++)
     {
     (void) fprintf(stderr, "\n%2d #          SYMBOL name  address \n", mem_space);
     for (i=0; i<SYMBOL_TABLE_SIZE; i++)
     {
     if (symbol_hash_by_addr_table[i][mem_space].address >= 0)
     (void) fprintf(stderr, "%4d %20s  %06lX \n", i, symbol_hash_by_addr_table[i][mem_space].name, symbol_hash_by_addr_table[i][mem_space].address);
     }
     }
     end debug */
}




