/*
 * Copyright (c) 1998 IEM
 *
 * MAAS help routines to access the board with/without maas driver
 *
 * purpose: test for MAAS PCI-Card and get memory-space of DSP
 *
 */

#include <stdio.h>
#include <fcntl.h>

#include "../maablib/maablib.h"

#define TIMEOUT 100000l

#define PBASE 0x100
#define PSIZE 10

int testprog[] = {
  0x08F4BD, 0x040003, 0x08F4BB, 0x010581,
  0x0CC905, 0x000004, 0x0A8503, 0x0C0104, 
  0x0A8523, 0x0C0104};

main()
{
  int i;
  int x;
  int dsp_ctrl;
  int dsp_status;
  long timeout;

  printf("Test maab biblio\n");


  /* - init pci Interface - */
  if(maab_init()!=MAAB_OK){
		fprintf(stdout,"something wrong happened :-((\n");
		return;
  }

  /* - forcing boot mode - */

  /* not implemented yet, or not possible ... */


  /* seting ctrls */
  dsp_ctrl = maab_r_hctr();

  printf("org HCTR: \n");
  maab_print_hctr(stdout,x);

  dsp_ctrl |= HCTR_HF0;     /* setting HF0 to 0, for boot loading */
  dsp_ctrl |= HCTR_HTF0;    /* setting DATA aligment */
  dsp_ctrl &= ~HCTR_HTF1;   /* to 01 = right aligned/24 Bit */
  dsp_ctrl &= ~HCTR_SFT;    /* unset prefetch, no prefetch */
  dsp_ctrl &= ~HCTR_TWSD;   /* unset target waitstate disable: up to 8 waitstates */

  maab_w_hctr(dsp_ctrl);

  /*test if suceeded*/
  if((x=maab_r_hctr()) != dsp_ctrl)
	 printf("host ctontrol not suceeded !\n");
  maab_print_hctr(stdout,x);


  /* -- write BOOT Programme to DSP -- */

  maab_print_hstr(stdout,maab_r_hstr());


  printf("trying to load progsize:");  

  timeout = TIMEOUT;
  while( (((dsp_status = maab_r_hstr()) & HSTR_HTRQ) == 0 /* Transmit request ? */
			 || (dsp_status & HSTR_TRDY) == 0)               /* Transmitter ready ? */
			&& --timeout > 0);                               /* or timeout */

  if(timeout <= 0){
	 fprintf(stdout,"Timeout trying to get write permission to HTXR on PCI \n");
	 maab_print_hstr(stdout,maab_r_hstr());
	 maab_exit();
	 return -1;
  }

  maab_w_data(PSIZE); /* write data */
  printf(" timing=%ld OK\n",TIMEOUT-timeout);

  maab_print_hstr(stdout,maab_r_hstr());

  printf("trying to load PBASE:");  

  timeout = TIMEOUT;
  while( (((dsp_status = maab_r_hstr()) & HSTR_HTRQ) == 0 /* Transmit request ? */
			 || (dsp_status & HSTR_TRDY) == 0)               /* Transmitter ready ? */
			&& --timeout > 0);                               /* or timeout */

  if(timeout <= 0){
	 fprintf(stdout,"Timeout trying to get write permission to HTXR on PCI \n");
	 maab_print_hstr(stdout,maab_r_hstr());
	 maab_exit();
	 return -1;
  }

  maab_w_data(PBASE); /* write data */
  printf(" timing=%ld OK\n",TIMEOUT-timeout);

  for(i=0;i<PSIZE;i++){
	 printf("trying to load programm byte %d = %6x:",i,testprog[i]);  

	 timeout = TIMEOUT;
	 while( (((dsp_status = maab_r_hstr()) & HSTR_HTRQ) == 0 /* Transmit request ? */
				|| (dsp_status & HSTR_TRDY) == 0)               /* Transmitter ready ? */
			  && --timeout > 0);                               /* or timeout */

	 if(timeout <= 0){
		fprintf(stdout,"Timeout trying to get write permission to HTXR on PCI \n");
		maab_print_hstr(stdout,maab_r_hstr());
		maab_exit();
		return -1;
	 }

	 maab_w_data(testprog[i]); /* write data */
	 printf(" timing=%ld OK\n",TIMEOUT-timeout);
  };

  
  maab_print_hstr(stdout,maab_r_hstr());
  
  dsp_ctrl = maab_r_hctr();
  printf("new HCTR: \n");
  maab_print_hctr(stdout,x);

  printf("setting HF0 to 0, to start programm\n");
  dsp_ctrl |= HCTR_HF0;     /* setting HF0 to 1, for stopping boot loading */
  maab_w_hctr(dsp_ctrl);

  maab_print_hstr(stdout,maab_r_hstr());

  /* --- testing prog --- */

  printf("Testing DSP prog:");
  

  /* setting HF2 to 1 */
  printf("setting HF2 to 1, to let DSP setting HF3 in Status Register\n");
  dsp_ctrl = maab_r_hctr();
  printf("new HCTR:\n");
  maab_print_hctr(stdout,x);

  dsp_ctrl |= HCTR_HF2;     /* setting HF0 to 1, for stopping boot loading */
  maab_w_hctr(dsp_ctrl);

  timeout=TIMEOUT;
  while( ((dsp_status = maab_r_hstr()) & HSTR_HF3) == 0  /* HF3 set */
			&& --timeout > 0);                              /* or timeout */

  maab_print_hstr(stdout,dsp_status);

  if(timeout <= 0)
	 fprintf(stdout,"Timeout trying to set HF3 with HF2 on DSP \n");
  else
	 printf(" timing=%ld OK\n",TIMEOUT-timeout);

  /* setting HF2 to 0 */
  printf("setting HF2 to 0, to let DSP clearing HF3 in Status Register\n");
  dsp_ctrl = maab_r_hctr();
  printf("new HCTR: \n");
  maab_print_hctr(stdout,x);

  dsp_ctrl &=  ~HCTR_HF2;     /* setting HF2 to 0 */
  maab_w_hctr(dsp_ctrl);

  timeout=TIMEOUT;
  while( ((dsp_status = maab_r_hstr()) & HSTR_HF3) != 0  /* HF3 set */
			&& --timeout > 0);                              /* or timeout */

  maab_print_hstr(stdout,dsp_status);

  if(timeout <= 0)
	 fprintf(stdout,"Timeout trying to clear HF3 with HF2 on DSP \n");
  else
	 printf(" timing=%ld OK\n",TIMEOUT-timeout);


  printf("Everything ok\n");
  maab_exit();
  return 0;
}
